@@ -8,9 +8,12 @@ import base64
 import os
 
 # initialize variables
-BASE_URL = 'https://58shnvgnlf.execute-api.us-east-1.amazonaws.com/sandbox/'
+BASE_URL = 'https://2hsbtjui63.execute-api.us-west-1.amazonaws.com/sandbox/'
 
 def init(api_key_id: str, api_key_secret: str, verbose: bool = False):
+    """
+    init is used to set the API key for the SDK. It should be called before any other SDK functions are called.
+    """
     token = base64.b64encode((f'{api_key_id}:{api_key_secret}').encode('utf-8')).decode('utf-8')
     os.environ['SUPERPOWERED_API_KEY'] = token
 
